@@ -353,6 +353,9 @@ CoinWarmStart* OsiXprSolverInterface::getWarmStart() const
       case 2:
 	ws->setArtifStatus(i, CoinWarmStartBasis::atUpperBound);
 	break;
+      case 3:
+ 	ws->setArtifStatus(i, CoinWarmStartBasis::isFree);
+ 	break;
       default:	// unknown row status
 	delete ws;
 	ws = NULL;
@@ -374,6 +377,9 @@ CoinWarmStart* OsiXprSolverInterface::getWarmStart() const
       case 2:
 	ws->setStructStatus( i, CoinWarmStartBasis::atUpperBound );
 	break;
+      case 3:
+  ws->setStructStatus(i, CoinWarmStartBasis::isFree);
+  break;
       default:	// unknown column status
 	delete ws;
 	ws = NULL;
@@ -910,6 +916,7 @@ OsiXprSolverInterface::getObjValue() const
    double  objconstant = 0;
 
    if ( isDataLoaded() ) {
+   //FIXME: this gives the value of the last LP relaxation solved in case of a MIP!
        XPRS_CHECKED( XPRSgetdblattrib, (prob_,XPRS_LPOBJVAL, &objvalue) );
        OsiSolverInterface::getDblParam(OsiObjOffset, objconstant);	
        		// Constant offset is not saved with the xpress representation,
@@ -1201,7 +1208,9 @@ OsiXprSolverInterface::setRowType(int index, char sense, double rightHandSide,
 
     XPRS_CHECKED( XPRSchgrowtype, (prob_,1, mindex, qrtype) );
     XPRS_CHECKED( XPRSchgrhs, (prob_,1, mindex, rhs) );
-    XPRS_CHECKED( XPRSchgrhsrange, (prob_,1, mindex, rng) );
+    // range is properly defined only for range-type rows, so we call XPRSchgrhsrange only for ranged rows
+    if (sense == 'R')
+      XPRS_CHECKED( XPRSchgrhsrange, (prob_,1, mindex, rng) );
 
     freeCachedResults();
   }
@@ -1748,7 +1757,7 @@ OsiXprSolverInterface::loadProblem(const int numcols, const int numrows,
   // Set column values to defaults if NULL pointer passed
   int nc = numcols;
   int nr = numrows;
-  int * len = new int[nc];
+  int * len = new int[nc+1];
   double * clb;  
   double * cub;
   double * ob;
@@ -1812,7 +1821,7 @@ OsiXprSolverInterface::loadProblem(const int numcols, const int numrows,
 
     fprintf(getLogFilePtr(),"  int vectorLengths[%d];\n",nc);
     for ( i=0; i<nc; i++ )
-      fprintf(getLogFilePtr(),"  vectorLengths[%d]=%d;\n",i,len[i]);
+      fprintf(getLogFilePtr(),"  vectorLengths[%d]=%d;\n",i,len[i+1]);
     
     fprintf(getLogFilePtr(),"  int indices[%d];\n",start[nc]);
     for ( i=0; i<start[nc]; i++ )
@@ -1832,7 +1841,7 @@ OsiXprSolverInterface::loadProblem(const int numcols, const int numrows,
 			const_cast<double*>(rowrng),
 			ob,
 			const_cast<int*>(start),
-			const_cast<int*>(len),
+			const_cast<int*>(len+1),
 			const_cast<int*>(index),
 			const_cast<double*>(value),
 			clb,
